=============================
Railroad
=============================

.. image:: https://badge.fury.io/py/railroad.png
    :target: http://badge.fury.io/py/railroad

.. image:: https://travis-ci.org/s-m-i-t-a/railroad.png?branch=master
    :target: https://travis-ci.org/s-m-i-t-a/railroad

.. image:: https://coveralls.io/repos/s-m-i-t-a/railroad/badge.svg?branch=master&service=github
    :target: https://coveralls.io/github/s-m-i-t-a/railroad?branch=master

.. image:: https://pypip.in/d/railroad/badge.png
    :target: https://pypi.python.org/pypi/railroad


A functional library for data processing.


Features
--------

* TODO

